/****** Object:  Database ist722_hhkhan_ca5_dw    Script Date: 8/7/2022 11:49:45 AM ******/

/* Group 5 */

USE ist722_hhkhan_ca5_dw
;

-- Create a schema to hold user views (set schema name on home page of workbook).
-- It would be good to do this only if the schema doesn't exist already.
GO
IF NOT EXISTS (SELECT * FROM sys.schemas WHERE name = 'g5')
EXEC('CREATE SCHEMA g5')
;
GO

/* Note that the SCD Type 2 column types and defaults had to be changed slightly from the exported macro values */

/* Drop table g5.FactOrderFulfillments */
/* Moving to top to avoid FK referential integrity errors */
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'g5.FactOrderFulfillments') AND OBJECTPROPERTY(id, N'IsUserTable') = 1)
DROP TABLE g5.FactOrderFulfillments 
;


/* Drop table g5.DimDate */
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'g5.DimDate') AND OBJECTPROPERTY(id, N'IsUserTable') = 1)
DROP TABLE g5.DimDate 
;

/* Create table g5.DimDate */
/* Changed IsWeekday to IsAWeekday Y/N */
/* Converted DayOfYear and Year to int*/
/* Convert Date to datetime */
CREATE TABLE g5.DimDate (
   [DateKey]  int   NOT NULL
,  [Date]  datetime   NULL
,  [FullDateUSA]  nchar(11)   NOT NULL
,  [DayOfWeek]  tinyint   NOT NULL
,  [DayName]  nchar(10)   NOT NULL
,  [DayOfMonth]  tinyint   NOT NULL
,  [DayOfYear]  int   NOT NULL
,  [WeekOfYear]  tinyint   NOT NULL
,  [MonthName]  nchar(10)   NOT NULL
,  [MonthOfYear]  tinyint   NOT NULL
,  [Quarter]  tinyint   NOT NULL
,  [QuarterName]  nchar(10)   NOT NULL
,  [Year]  int   NOT NULL
,  [IsAWeekday]  char(1)  DEFAULT 0 NOT NULL
, CONSTRAINT [PK_g5.DimDate] PRIMARY KEY CLUSTERED 
( [DateKey] )
) ON [PRIMARY]
;


INSERT INTO g5.DimDate (DateKey, Date, FullDateUSA, DayOfWeek, DayName, DayOfMonth, DayOfYear, WeekOfYear, MonthName, MonthOfYear, Quarter, QuarterName, Year, IsAWeekday)
VALUES (-1, NULL, 'Unk date', 0, 'Unk date', 0, 0, 0, 'Unk month', 0, 0, 'Unk qtr', 0, '?')
;

-- User-oriented view definition
GO
IF EXISTS (select * from sys.views where object_id=OBJECT_ID(N'[g5].[Date]'))
DROP VIEW [g5].[Date]
GO
CREATE VIEW [g5].[Date] AS 
SELECT [DateKey] AS [DateKey]
, [Date] AS [Date]
, [FullDateUSA] AS [FullDateUSA]
, [DayOfWeek] AS [DayOfWeek]
, [DayName] AS [DayName]
, [DayOfMonth] AS [DayOfMonth]
, [DayOfYear] AS [DayOfYear]
, [WeekOfYear] AS [WeekOfYear]
, [MonthName] AS [MonthName]
, [MonthOfYear] AS [MonthOfYear]
, [Quarter] AS [Quarter]
, [QuarterName] AS [QuarterName]
, [Year] AS [Year]
, [IsAWeekday] AS [IsAWeekday]
FROM g5.DimDate
GO


/* Drop table g5.DimCustomer */
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'g5.DimCustomer') AND OBJECTPROPERTY(id, N'IsUserTable') = 1)
DROP TABLE g5.DimCustomer 
;
GO

/* Create table g5.DimCustomer */
CREATE TABLE g5.DimCustomer (
   [CustomerKey]  int IDENTITY  NOT NULL
,  [CustomerId]  int   NOT NULL
,  [CustomerLineOfBusiness]  varchar(30)  NOT NULL
,  [CustomerFirstName]  varchar(50)   NOT NULL
,  [CustomerLastName]  varchar(50)   NOT NULL
,  [CustomerStreetAddress]  varchar(1000)   NOT NULL
,  [CustomerCity]  varchar(50)   NOT NULL
,  [CustomerState]  char(2)   NOT NULL
,  [CustomerZipCode]  varchar(20)   NOT NULL
,  [CustomerEmail]  varchar(200)   NOT NULL
,  [CustomerPhone]  varchar(30)   NOT NULL
,  [CustomerFax]  varchar(30)   NOT NULL
,  [RowIsCurrent]  bit   DEFAULT 1 NOT NULL
,  [RowStartDate]  datetime  DEFAULT '12/31/1899' NOT NULL
,  [RowEndDate]  datetime  DEFAULT '12/31/9999' NOT NULL
,  [RowChangeReason]  nvarchar(200)   NULL
, CONSTRAINT [PK_g5.DimCustomer] PRIMARY KEY CLUSTERED 
( [CustomerKey] )
) ON [PRIMARY]
;

SET IDENTITY_INSERT g5.DimCustomer ON
;
INSERT INTO g5.DimCustomer (CustomerKey, CustomerId, CustomerLineOfBusiness, CustomerFirstName, CustomerLastName, CustomerStreetAddress, CustomerCity, CustomerState, CustomerZipCode, CustomerEmail, CustomerPhone, CustomerFax, RowIsCurrent, RowStartDate, RowEndDate, RowChangeReason)
VALUES (-1, -1, 'Unknown Business Line', 'Unknown First Name', 'Unknown Last Name', 'Unknown Street Address', 'Unknown City', '??', 'Unknown Zip Code', 'Unknown Email', 'Unknown Phone Number', 'Unknown Fax Number', 1, '12/31/1899', '12/31/9999', 'N/A')
;
SET IDENTITY_INSERT g5.DimCustomer OFF
;

-- User-oriented view definition
GO
IF EXISTS (select * from sys.views where object_id=OBJECT_ID(N'[g5].[Customer]'))
DROP VIEW [g5].[Customer]
GO
CREATE VIEW [g5].[Customer] AS 
SELECT [CustomerKey] AS [CustomerKey]
, [CustomerId] AS [CustomerId]
, [CustomerLineOfBusiness] AS [CustomerLineOfBusiness]
, [CustomerFirstName] AS [CustomerFirstName]
, [CustomerLastName] AS [CustomerLastName]
, [CustomerStreetAddress] AS [CustomerStreetAddress]
, [CustomerCity] AS [CustomerCity]
, [CustomerState] AS [CustomerState]
, [CustomerZipCode] AS [CustomerZipCode]
, [CustomerEmail] AS [CustomerEmail]
, [CustomerPhone] AS [CustomerPhone]
, [CustomerFax] AS [CustomerFax]
, [RowIsCurrent]  AS [RowIsCurrent]
, [RowStartDate]  AS [RowStartDate]
, [RowEndDate]  AS [RowEndDate]
, [RowChangeReason]  AS [RowChangeReason]
FROM g5.DimCustomer
GO


/* Drop table g5.DimShipper */
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'g5.DimShipper') AND OBJECTPROPERTY(id, N'IsUserTable') = 1)
DROP TABLE g5.DimShipper 
;

/* Create table g5.DimShipper */
CREATE TABLE g5.DimShipper (
   [ShipperKey]  int IDENTITY  NOT NULL
,  [ShipperName]  varchar(20)   NOT NULL
, CONSTRAINT [PK_g5.DimShipper] PRIMARY KEY CLUSTERED 
( [ShipperKey] )
) ON [PRIMARY]
;


SET IDENTITY_INSERT g5.DimShipper ON
;
INSERT INTO g5.DimShipper (ShipperKey, ShipperName)
VALUES (-1, 'Unknown Shipper')
;

/* Automatically add FudgeFlix as a shipper option */
INSERT INTO g5.DimShipper (ShipperKey, ShipperName)
VALUES (-2, 'FudgeFlix')
;
SET IDENTITY_INSERT g5.DimShipper OFF
;

-- User-oriented view definition
GO
IF EXISTS (select * from sys.views where object_id=OBJECT_ID(N'[g5].[Shipper]'))
DROP VIEW [g5].[Shipper]
GO
CREATE VIEW [g5].[Shipper] AS 
SELECT [ShipperKey] AS [ShipperKey]
, [ShipperName] AS [ShipperName]
FROM g5.DimShipper
GO



/* Drop table g5.DimTitle */
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'g5.DimTitle') AND OBJECTPROPERTY(id, N'IsUserTable') = 1)
DROP TABLE g5.DimTitle 
;

/* Create table g5.DimTitle */
CREATE TABLE g5.DimTitle (
   [TitleKey]  int IDENTITY  NOT NULL
,  [TitleId]  varchar(20)   NOT NULL
,  [TitleName]  varchar(200)   NOT NULL
,  [RowIsCurrent]  bit   DEFAULT 1 NOT NULL
,  [RowStartDate]  datetime  DEFAULT '12/31/1899' NOT NULL
,  [RowEndDate]  datetime  DEFAULT '12/31/9999' NOT NULL
,  [RowChangeReason]  nvarchar(200)   NULL
, CONSTRAINT [PK_g5.DimTitle] PRIMARY KEY CLUSTERED 
( [TitleKey] )
) ON [PRIMARY]
;


SET IDENTITY_INSERT g5.DimTitle ON
;
INSERT INTO g5.DimTitle (TitleKey, TitleId, TitleName, RowIsCurrent, RowStartDate, RowEndDate, RowChangeReason)
VALUES (-1, '', 'Unknown Title', 1, '12/31/1899', '12/31/9999', 'N/A')
;
SET IDENTITY_INSERT g5.DimTitle OFF
;

-- User-oriented view definition
GO
IF EXISTS (select * from sys.views where object_id=OBJECT_ID(N'[g5].[Title]'))
DROP VIEW [g5].[Title]
GO
CREATE VIEW [g5].[Title] AS 
SELECT [TitleKey] AS [TitleKey]
, [TitleId] AS [TitleId]
, [TitleName] AS [TitleName]
, [RowIsCurrent] AS [Row Is Current]
, [RowStartDate] AS [Row Start Date]
, [RowEndDate] AS [Row End Date]
, [RowChangeReason] AS [Row Change Reason]
FROM g5.DimTitle
GO


/* Create table g5.FactOrderFulfillments */
CREATE TABLE g5.FactOrderFulfillments (
   [OrderFulfillmentOrderId]  int   NOT NULL
,  [OrderFulfillmentLineOfBusiness]  varchar(30)   NOT NULL
,  [OrderFulfillmentOrderDate]  int   NOT NULL
,  [OrderFulfillmentShipDate]  int   NULL
,  [OrderFulfillmentShipLag]  int   NULL
,  [OrderFulfillmentShipperId]  int   NULL
,  [OrderFulfillmentCustomerId]  int   NOT NULL
,  [OrderFulfillmentMovieTitle]  int   NULL
,  [OrderFulfillmentItemsShipped]  int   NULL
,  [OrderFulfillmentReturnDate]  int   NULL
,  [OrderFulfillmentReturnLag]  int   NULL
, CONSTRAINT [PK_g5.FactOrderFulfillments] PRIMARY KEY NONCLUSTERED 
( [OrderFulfillmentOrderId], [OrderFulfillmentLineOfBusiness] )
) ON [PRIMARY]
;


-- User-oriented view definition
GO
IF EXISTS (select * from sys.views where object_id=OBJECT_ID(N'[g5].[OrderFulfillments]'))
DROP VIEW [g5].[OrderFulfillments]
GO
CREATE VIEW [g5].[OrderFulfillments] AS 
SELECT [OrderFulfillmentOrderId] AS [OrderFulfillmentOrderId]
, [OrderFulfillmentLineOfBusiness] AS [OrderFulfillmentLineOfBusiness]
, [OrderFulfillmentOrderDate] AS [OrderFulfillmentOrderDate]
, [OrderFulfillmentShipDate] AS [OrderFulfillmentShipDate]
, [OrderFulfillmentShipLag] AS [OrderFulfillmentShipLag]
, [OrderFulfillmentShipperId] AS [OrderFulfillmentShipperId]
, [OrderFulfillmentCustomerId] AS [OrderFulfillmentCustomerId]
, [OrderFulfillmentMovieTitle] AS [OrderFulfillmentMovieTitle]
, [OrderFulfillmentItemsShipped] AS [OrderFulfillmentItemsShipped]
, [OrderFulfillmentReturnDate] AS [OrderFulfillmentReturnDate]
, [OrderFulfillmentReturnLag] AS [OrderFulfillmentReturnLag]
FROM g5.FactOrderFulfillments
GO



ALTER TABLE g5.FactOrderFulfillments ADD CONSTRAINT
   FK_g5_FactOrderFulfillments_OrderFulfillmentOrderDate FOREIGN KEY
   (
   OrderFulfillmentOrderDate
   ) REFERENCES g5.DimDate
   ( DateKey )
     ON UPDATE  NO ACTION
     ON DELETE  NO ACTION
;
 
ALTER TABLE g5.FactOrderFulfillments ADD CONSTRAINT
   FK_g5_FactOrderFulfillments_OrderFulfillmentShipDate FOREIGN KEY
   (
   OrderFulfillmentShipDate
   ) REFERENCES g5.DimDate
   ( DateKey )
     ON UPDATE  NO ACTION
     ON DELETE  NO ACTION
;
 
ALTER TABLE g5.FactOrderFulfillments ADD CONSTRAINT
   FK_g5_FactOrderFulfillments_OrderFulfillmentShipperId FOREIGN KEY
   (
   OrderFulfillmentShipperId
   ) REFERENCES g5.DimShipper
   ( ShipperKey )
     ON UPDATE  NO ACTION
     ON DELETE  NO ACTION
;
 
ALTER TABLE g5.FactOrderFulfillments ADD CONSTRAINT
   FK_g5_FactOrderFulfillments_OrderFulfillmentCustomerId FOREIGN KEY
   (
   OrderFulfillmentCustomerId
   ) REFERENCES g5.DimCustomer
   ( CustomerKey )
     ON UPDATE  NO ACTION
     ON DELETE  NO ACTION
;
 
ALTER TABLE g5.FactOrderFulfillments ADD CONSTRAINT
   FK_g5_FactOrderFulfillments_OrderFulfillmentMovieTitle FOREIGN KEY
   (
   OrderFulfillmentMovieTitle
   ) REFERENCES g5.DimTitle
   ( TitleKey )
     ON UPDATE  NO ACTION
     ON DELETE  NO ACTION
;
 
ALTER TABLE g5.FactOrderFulfillments ADD CONSTRAINT
   FK_g5_FactOrderFulfillments_OrderFulfillmentReturnDate FOREIGN KEY
   (
   OrderFulfillmentReturnDate
   ) REFERENCES g5.DimDate
   ( DateKey )
     ON UPDATE  NO ACTION
     ON DELETE  NO ACTION
;
 
